(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     15802,        407]
NotebookOptionsPosition[     15228,        385]
NotebookOutlinePosition[     15670,        402]
CellTagsIndexPosition[     15627,        399]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Math Horizons   \n",
  FontFamily->"Courier",
  FontSize->24],
 "November 2009 - The Playground"
}], "Text",
 FontSize->16],

Cell[TextData[{
 StyleBox["Problem 230",
  FontWeight->"Bold"],
 " asks what shape must be removed from the plane ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", "a"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " in order that the sculpture can rotate freely? As in the article, we \
suppose the sculpture is composed of an inclined rod that forms an angle \
\[Alpha] above the horizontal (0 < \[Alpha] < \[Pi]/2). This rod is attached \
at its midpoint to a horizontal arm of length ",
 StyleBox["r",
  FontSlant->"Italic"],
 ", and this arm rotates about a vertical axis. We take the origin to be the \
point where the arm meets the vertical axis, and measure the rotation angle \
\[Theta] counterclockwise from the positive ",
 StyleBox["x",
  FontSlant->"Italic"],
 " axis when viewed from above. "
}], "Text"],

Cell[TextData[{
 "The ",
 StyleBox["Manipulate", "MR"],
 " below illustrates that the solution is a hyperbola which opens vertically \
if ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"r", "<"}], "|", "a", "|"}], TraditionalForm]]],
 " and which opens horizontally if ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"r", ">"}], "|", "a", "|"}], TraditionalForm]]],
 ". "
}], "Text"],

Cell["\<\
Push the \"+\" button to the right of the top slider to open a control panel. \
Push the \"play\" button to set the sculpture in motion. While it is \
spinning, adjust the parameters on the bottom to watch it change in real \
time. ENJOY!\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"h", "=", "10"}], ",", 
       RowBox[{"d", "=", ".1"}], ",", 
       RowBox[{"l", "=", "5"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"Graphics3D", "[", 
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"GrayLevel", "[", ".5", "]"}], ",", 
            RowBox[{"Cylinder", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "0", ",", 
                  RowBox[{"-", "1"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], ",", 
              "5"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"GrayLevel", "[", ".5", "]"}], ",", 
            RowBox[{"Cylinder", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "0", ",", 
                  RowBox[{"h", "+", "d"}]}], "}"}]}], "}"}], ",", "d"}], 
             "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Cylinder", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "0", ",", "h"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"r", " ", 
                 RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
                RowBox[{"r", " ", 
                 RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", "h"}], "}"}]}],
              "}"}], ",", "d"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Cylinder", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"r", " ", 
                  RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
                 RowBox[{"l", " ", 
                  RowBox[{"Sin", "[", "\[Theta]", "]"}], 
                  RowBox[{"Cos", "[", "\[Alpha]", "]"}]}]}], ",", 
                RowBox[{
                 RowBox[{"r", " ", 
                  RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
                 RowBox[{"l", " ", 
                  RowBox[{"Cos", "[", "\[Theta]", "]"}], 
                  RowBox[{"Cos", "[", "\[Alpha]", "]"}]}]}], ",", 
                RowBox[{"h", "+", 
                 RowBox[{"l", " ", 
                  RowBox[{"Sin", "[", "\[Alpha]", "]"}]}]}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"r", " ", 
                  RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
                 RowBox[{"l", " ", 
                  RowBox[{"Sin", "[", "\[Theta]", "]"}], 
                  RowBox[{"Cos", "[", "\[Alpha]", "]"}]}]}], ",", 
                RowBox[{
                 RowBox[{"r", " ", 
                  RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
                 RowBox[{"l", " ", 
                  RowBox[{"Cos", "[", "\[Theta]", "]"}], 
                  RowBox[{"Cos", "[", "\[Alpha]", "]"}]}]}], ",", 
                RowBox[{"h", "-", 
                 RowBox[{"l", " ", 
                  RowBox[{"Sin", "[", "\[Alpha]", "]"}]}]}]}], "}"}]}], "}"}],
             ",", "d"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Opacity", "[", ".7", "]"}], ",", 
            RowBox[{"Polygon", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "5"}], ",", "a", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"5", ",", "a", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"5", ",", "a", ",", 
                 RowBox[{"2", "h"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "5"}], ",", "a", ",", 
                 RowBox[{"2", "h"}]}], "}"}]}], "}"}], "]"}]}], "}"}]}], 
         "\[IndentingNewLine]", "}"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"r", " ", 
             RowBox[{"Sec", "[", "t", "]"}]}], "-", 
            RowBox[{"a", " ", 
             RowBox[{"Tan", "[", "t", "]"}]}]}], ",", "a", ",", 
           RowBox[{"h", "+", 
            RowBox[{
             RowBox[{"Tan", "[", "\[Alpha]", "]"}], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"a", " ", 
                RowBox[{"Sec", "[", "t", "]"}]}], "-", 
               RowBox[{"r", " ", 
                RowBox[{"Tan", "[", "t", "]"}]}]}], ")"}]}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", 
           RowBox[{
            RowBox[{"-", "\[Pi]"}], "/", "2"}], ",", 
           RowBox[{"\[Pi]", "/", "2"}]}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"RGBColor", "[", 
           RowBox[{"1", ",", "1", ",", "0"}], "]"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"r", " ", 
             RowBox[{"Sec", "[", "t", "]"}]}], "-", 
            RowBox[{"a", " ", 
             RowBox[{"Tan", "[", "t", "]"}]}]}], ",", "a", ",", 
           RowBox[{"h", "+", 
            RowBox[{
             RowBox[{"Tan", "[", "\[Alpha]", "]"}], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"a", " ", 
                RowBox[{"Sec", "[", "t", "]"}]}], "-", 
               RowBox[{"r", " ", 
                RowBox[{"Tan", "[", "t", "]"}]}]}], ")"}]}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", 
           RowBox[{"\[Pi]", "/", "2"}], ",", 
           RowBox[{"3", 
            RowBox[{"\[Pi]", "/", "2"}]}]}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"RGBColor", "[", 
           RowBox[{"1", ",", "1", ",", "0"}], "]"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", 
            RowBox[{"2", "h"}]}], "}"}]}], "}"}]}]}], "\[IndentingNewLine]", 
      "]"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", ",", 
     RowBox[{
      RowBox[{"-", "\[Pi]"}], "/", "2"}], ",", 
     RowBox[{"3", 
      RowBox[{"\[Pi]", "/", "2"}]}], ",", 
     RowBox[{"ControlPlacement", "\[Rule]", "Top"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", ".3"}], "}"}], ",", "0", ",", "4"}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Alpha]", ",", 
       RowBox[{"\[Pi]", "/", "6"}]}], "}"}], ",", "0", ",", 
     RowBox[{"\[Pi]", "/", "2"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r", ",", "2"}], "}"}], ",", ".5", ",", "4"}], "}"}], ",", 
   RowBox[{"ControlPlacement", "\[Rule]", "Bottom"}]}], "\[IndentingNewLine]",
   "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 
    2.0100000000000002`, $CellContext`r$$ = 2.35, $CellContext`\[Alpha]$$ = 
    0.4162610266006476, $CellContext`\[Theta]$$ = 4.008777759065092, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`\[Theta]$$], Rational[-1, 2] Pi, Rational[3, 2] Pi}, {{
       Hold[$CellContext`a$$], 0.3}, 0, 4}, {{
       Hold[$CellContext`\[Alpha]$$], Rational[1, 6] Pi}, 0, Rational[1, 2] 
      Pi}, {{
       Hold[$CellContext`r$$], 2}, 0.5, 4}}, Typeset`size$$ = {
    322., {267., 273.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`\[Theta]$569986$$ = 
    0, $CellContext`a$569987$$ = 0, $CellContext`\[Alpha]$569988$$ = 
    0, $CellContext`r$569989$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0.3, $CellContext`r$$ = 
        2, $CellContext`\[Alpha]$$ = 
        Rational[1, 6] Pi, $CellContext`\[Theta]$$ = Rational[-1, 2] Pi}, 
      "ControllerVariables" :> {
        Hold[$CellContext`\[Theta]$$, $CellContext`\[Theta]$569986$$, 0], 
        Hold[$CellContext`a$$, $CellContext`a$569987$$, 0], 
        Hold[$CellContext`\[Alpha]$$, $CellContext`\[Alpha]$569988$$, 0], 
        Hold[$CellContext`r$$, $CellContext`r$569989$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`h$ = 10, $CellContext`d$ = 0.1, $CellContext`l$ = 
         5}, 
        Show[
         Graphics3D[{{
            GrayLevel[0.5], 
            Cylinder[{{0, 0, -1}, {0, 0, 0}}, 5]}, {
            GrayLevel[0.5], 
            
            Cylinder[{{0, 0, 0}, {
              0, 0, $CellContext`h$ + $CellContext`d$}}, $CellContext`d$]}, 
           
           Cylinder[{{
             0, 0, $CellContext`h$}, {$CellContext`r$$ 
              Cos[$CellContext`\[Theta]$$], $CellContext`r$$ 
              Sin[$CellContext`\[Theta]$$], $CellContext`h$}}, \
$CellContext`d$], 
           
           Cylinder[{{$CellContext`r$$ 
               Cos[$CellContext`\[Theta]$$] - $CellContext`l$ 
              Sin[$CellContext`\[Theta]$$] 
              Cos[$CellContext`\[Alpha]$$], $CellContext`r$$ 
               Sin[$CellContext`\[Theta]$$] + $CellContext`l$ 
               Cos[$CellContext`\[Theta]$$] 
               Cos[$CellContext`\[Alpha]$$], $CellContext`h$ + \
$CellContext`l$ Sin[$CellContext`\[Alpha]$$]}, {$CellContext`r$$ 
               Cos[$CellContext`\[Theta]$$] + $CellContext`l$ 
               Sin[$CellContext`\[Theta]$$] 
               Cos[$CellContext`\[Alpha]$$], $CellContext`r$$ 
               Sin[$CellContext`\[Theta]$$] - $CellContext`l$ 
              Cos[$CellContext`\[Theta]$$] 
              Cos[$CellContext`\[Alpha]$$], $CellContext`h$ - $CellContext`l$ 
              Sin[$CellContext`\[Alpha]$$]}}, $CellContext`d$], {
            Opacity[0.7], 
            
            Polygon[{{-5, $CellContext`a$$, 0}, {5, $CellContext`a$$, 0}, {
              5, $CellContext`a$$, 2 $CellContext`h$}, {-5, $CellContext`a$$, 
               2 $CellContext`h$}}]}}], 
         ParametricPlot3D[{$CellContext`r$$ 
            Sec[$CellContext`t] - $CellContext`a$$ 
           Tan[$CellContext`t], $CellContext`a$$, $CellContext`h$ + 
           Tan[$CellContext`\[Alpha]$$] ($CellContext`a$$ 
              Sec[$CellContext`t] - $CellContext`r$$ 
             Tan[$CellContext`t])}, {$CellContext`t, (-Pi)/2, Pi/2}, 
          PlotStyle -> RGBColor[1, 1, 0]], 
         ParametricPlot3D[{$CellContext`r$$ 
            Sec[$CellContext`t] - $CellContext`a$$ 
           Tan[$CellContext`t], $CellContext`a$$, $CellContext`h$ + 
           Tan[$CellContext`\[Alpha]$$] ($CellContext`a$$ 
              Sec[$CellContext`t] - $CellContext`r$$ 
             Tan[$CellContext`t])}, {$CellContext`t, Pi/2, 3 (Pi/2)}, 
          PlotStyle -> RGBColor[1, 1, 0]], 
         PlotRange -> {{-5, 5}, {-5, 5}, {-1, 2 $CellContext`h$}}]], 
      "Specifications" :> {{$CellContext`\[Theta]$$, Rational[-1, 2] Pi, 
         Rational[3, 2] Pi, ControlPlacement -> 
         Top}, {{$CellContext`a$$, 0.3}, 0, 
         4}, {{$CellContext`\[Alpha]$$, Rational[1, 6] Pi}, 0, Rational[1, 2] 
         Pi}, {{$CellContext`r$$, 2}, 0.5, 4}}, 
      "Options" :> {ControlPlacement -> Bottom}, "DefaultOptions" :> {}],
     ImageSizeCache->{375., {377.21875, 383.78125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output"]
}, {2}]]
},
WindowSize->{727, 807},
WindowMargins->{{135, Automatic}, {Automatic, 32}},
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 150, 6, 71, "Text"],
Cell[698, 28, 828, 20, 126, "Text"],
Cell[1529, 50, 394, 15, 55, "Text"],
Cell[1926, 67, 262, 5, 70, "Text"],
Cell[CellGroupData[{
Cell[2213, 76, 7896, 204, 528, "Input"],
Cell[10112, 282, 5103, 100, 781, "Output"]
}, {2}]]
}
]
*)

(* End of internal cache information *)
